bus

package
v0.0.0-...-d8c2073 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Bus

type Bus interface {
	command.CommandSender
	command.EventPublisher
	// Bind binds handlers v type, v can be either command or event.
	Bind(v interface{}, handlers []command.Handler) error
}

Bus is an interface for building bus to process both commands and evets.

func NewSyncBus

func NewSyncBus(middlewares ...command.Middleware) Bus

Jump to