Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Bus ¶
type Bus interface {
command.CommandSender
command.EventPublisher
// Bind binds handlers v type, v can be either command or event.
Bind(v interface{}, handlers []command.Handler) error
}
Bus is an interface for building bus to process both commands and evets.
func NewSyncBus ¶
func NewSyncBus(middlewares ...command.Middleware) Bus
Click to show internal directories.
Click to hide internal directories.